@@ -25,8 +25,8 @@ from more_itertools import bucket
 from os2mo_dar_client import DARClient
 from os2mo_helpers.mora_helpers import MoraHelper
 from ra_utils.load_settings import load_settings
+from ra_utils.tqdm_wrapper import tqdm
 from retrying import retry
-from tqdm import tqdm
 
 
 logger = logging.getLogger("LoraCache")
