@@ -13,6 +13,7 @@ from typing import Optional
 from typing import Tuple
 
 import click
+import sentry_sdk
 from ra_utils.apply import apply
 from ra_utils.catchtime import catchtime
 from ra_utils.jinja_filter import create_filters
@@ -20,6 +21,7 @@ from ra_utils.lazy_dict import LazyDict
 from ra_utils.lazy_dict import LazyEval
 from ra_utils.lazy_dict import LazyEvalBare
 from ra_utils.load_settings import load_settings
+from ra_utils.tqdm_wrapper import tqdm
 
 from .ad_exceptions import NoActiveEngagementsException
 from .ad_exceptions import NoPrimaryEngagementException
@@ -28,7 +30,6 @@ from .ad_reader import ADParameterReader
 from .ad_writer import ADWriter
 from .read_ad_conf_settings import injected_settings
 from exporters.sql_export.lora_cache import LoraCache
-from helpers import tqdm
 
 logger = logging.getLogger("CreateAdUsers")
 export_logger = logging.getLogger("export")
@@ -507,6 +508,9 @@ def ad_life_cycle(
         skip_occupied_names_check=skip_occupied_names_check,
     )
 
+    if "crontab.SENTRY_DSN" in sync._settings:
+        sentry_sdk.init(dsn=sync._settings["crontab.SENTRY_DSN"])
+
     if preview_command_for_uuid:
         run_preview_command_for_uuid(sync, str(preview_command_for_uuid))
         return
